;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "elisp-dev-mcp" "20260630.1120"
  "MCP server for agentic Elisp development."
  '((emacs          "27.1")
    (mcp-server-lib "0.4.0"))
  :url "https://github.com/laurynas-biveinis/elisp-dev-mcp"
  :commit "d70a8f38ededefb7e3d11f3e2b519bf754a54d1a"
  :revdesc "d70a8f38eded"
  :keywords '("tools" "development"))
